@@ -457,6 +457,7 @@ split_event <- function(data,dic,event_form,which=NULL){
 #' @param event_form Data frame  containing the correspondence of each event with each form.
 #' @param which Character string specifying a form if only data for that form is desired.
 #' @param wide Logical indicating if the dataset should be returned in a wide format (`TRUE`) or long format (`FALSE`).
+#' @importFrom magrittr `%>%`
 
 split_form <- function(data, dic, event_form = NULL, which = NULL, wide=FALSE){
 
@@ -479,6 +480,16 @@ split_form <- function(data, dic, event_form = NULL, which = NULL, wide=FALSE){
     repeat_instrument <- FALSE
   }
 
+  #Check if the project has repeated instruments
+  if("redcap_repeat_instrument" %in% names(data)) {
+    repeat_instrument <- dplyr::case_when(
+      any(!is.na(data$redcap_repeat_instrument)) ~ TRUE,
+      TRUE ~ FALSE
+    )
+  } else {
+    repeat_instrument <- FALSE
+  }
+
   #Find basic REDCap variables found in the database
   basic_redcap_vars <- c("record_id","redcap_event_name","redcap_repeat_instrument", "redcap_repeat_instrument.factor","redcap_repeat_instance","redcap_data_access_group","redcap_event_name.factor", "redcap_data_access_group.factor", "redcap_survey_identifier")
 
@@ -545,6 +556,29 @@ split_form <- function(data, dic, event_form = NULL, which = NULL, wide=FALSE){
                                       dplyr::select(tidyselect::all_of(unique(c(basic_redcap_vars, .x))))))
   }
 
+  if(repeat_instrument)  {
+    form_check <- data %>%
+    dplyr::distinct(.data$redcap_repeat_instrument, .data$redcap_repeat_instrument.factor)
+
+    ndata <- ndata %>%
+      dplyr::left_join(form_check, by = dplyr::join_by("form" == "redcap_repeat_instrument")) %>%
+      dplyr::relocate("form_factor" = "redcap_repeat_instrument.factor", .after = form) %>%
+      dplyr::mutate(df = purrr::map2(.data$form_factor, .data$df, ~ {
+        if (is.na(.x)) {
+          .y %>%
+            dplyr::filter(is.na(.data$redcap_repeat_instrument.factor)) %>%
+            dplyr::select(-dplyr::starts_with("redcap_repeat_instrument"))
+        } else {
+          .y %>%
+            dplyr::filter(.data$redcap_repeat_instrument.factor == .x) %>%
+            dplyr::mutate(redcap_repeat_instrument = redcap_repeat_instrument.factor) %>%
+            dplyr::select(-redcap_repeat_instrument.factor)
+        }
+      })) %>%
+      dplyr::select(-"form_factor")
+  }
+
+
   if(repeat_instrument)  {
     form_check <- data |>
     dplyr::distinct(dplyr::pick(dplyr::contains("redcap_repeat_instrument")))
